--[[
Callback events  

OPTIONS_UPDATE 
	args:  nil
		
	Fired when ever the GUI options are changed
		
]]
local PetBattleTeams = LibStub("AceAddon-3.0"):GetAddon("PetBattleTeams")
local GUI = PetBattleTeams:NewModule("GUI")
local _


function GUI:OnInitialize()
	self.callbacks = LibStub("CallbackHandler-1.0"):New(self)
	
	local db = LibStub("AceDB-3.0"):New("PetBattleTeamsDB", {} , true)
	local name = self:GetName()
	
	local defaults = {
		global = {
			attached = true,
			locked = false,
			hideInCombat = true,
			x = 0,
			y = 0,
			h = 606,
		}
	}
	
	self.db = db:RegisterNamespace(name, defaults)
	self.mainFrame =  GUI:CreateMainFrame()
	self.mainFrame:SetPoint("TOPLEFT",UIParent)
	
	self.mainFrame:SetLocked(self:GetLocked())
	self.mainFrame:SetAttached(self:GetAttached())
	
	self.mainFrame:Show()
	
	--local pos = self.db.global
	--self.mainFrame:SetPosition(pos.x,pos.y,pos.h)
end

function GUI:SetAttached(enabled)
	if UnitAffectingCombat("player") then print("PetBattleTeams: Can't change attachment during combat") return end
	self.db.global.attached = enabled
	self.mainFrame:SetAttached(enabled)
end

function GUI:SetHideInCombat(enabled )
	self.db.global.hideInCombat = enabled
end

function GUI:SetLocked(enabled)
	self.db.global.locked = enabled
	self.mainFrame:SetLocked(enabled)
	self.callbacks:Fire("OPTIONS_UPDATE")
end

function GUI:GetAttached()
	return self.db.global.attached
end

function GUI:GetLocked()
	return self.db.global.locked
end

function GUI:GetHideInCombat()
	return self.db.global.hideInCombat
end

function GUI:GetPosition()
	local db = self.db.global
	return db.x,db.y,db.h
end

function GUI:SetPosition(x,y,h)
	local db = self.db.global
	db.x,db.y,db.h = x,y,h
end

function GUI:ResetUI()
	self:SetLocked(false)
	self:SetAttached(true)
	self:SetHideInCombat(true)
end







